/*
 * connections.sp
 * Copyright (c) 2021 Ed <https://d-rine.com/~ed/>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#define PLUGIN_VERSION		"0.2"
#define PLUGIN_NAME		"Player Connection Status"

#include <sourcemod>
#include "edlib.sp"

public Plugin:myinfo =
{
	name = PLUGIN_NAME,
	author = "EDSHOT",
	description = "Print a message when a player connects/disconnects.",
	version = PLUGIN_VERSION
};

public void OnPluginStart()
{
	HookEvent("player_connect", Event_PlayerConnect, EventHookMode_Pre);
	HookEvent("player_disconnect", Event_PlayerDisconnect, EventHookMode_Pre);
	LoadTranslations("connections.phrases");
}

public void OnPluginEnd()
{
	UnhookEvent("player_connect", Event_PlayerConnect, EventHookMode_Pre);
	UnhookEvent("player_disconnect", Event_PlayerDisconnect, EventHookMode_Pre);
}

public Action:Event_PlayerConnect(Event event, const char[] name, bool dontBroadcast)
{
	if (event.GetBool("bot")) return Plugin_Handled;
	char buf[256];
	GetEventString(event, "name", buf, sizeof(buf));
	PrintToChatAllTranslated1C("Cstrike_TitlesTXT_Game_connected", "", "", buf);
	return Plugin_Handled;
}

public Action:Event_PlayerDisconnect(Event event, const char[] name, bool dontBroadcast)
{
	if (event.GetBool("bot")) return Plugin_Handled;
	int pid = GetClientOfUserId(event.GetInt("userid"));
	if (pid == 0 || IsFakeClient(pid)) return Plugin_Handled;
	char buf[256];
	char buf2[256];
	GetEventString(event, "name", buf, sizeof(buf));
	GetEventString(event, "reason", buf2, sizeof(buf2));
	PrintToChatAllTranslated2C("Cstrike_TitlesTXT_Game_disconnected", "", "", buf, buf2);
	return Plugin_Handled;
}
